DATA_TYPES_OF_R_TYPE: All available data types, mapped from their respective R...

DATA_TYPES_OF_R_TYPER Documentation

All available data types, mapped from their respective R types

Description

All available data types, mapped from their respective R types

Usage

DATA_TYPES_OF_R_TYPE

See Also

prep_dq_data_type_of


dataquieR documentation built on May 12, 2026, 1:06 a.m.