Function to identify inadmissible measurements according to hard limits (multiple variables)
acc_distributions(
resp_vars = NULL,
label_col,
group_vars = NULL,
study_data,
meta_data
)variable list the names of the measurement variables
variable attribute the name of the column in the metadata with labels of variables
variable list the name of the observer, device or reader variable
data.frame the data frame that contains the measurements
data.frame the data frame that contains metadata attributes of study data
A list with:
Select all variables of type float or integer in the study data
Remove missing codes from the study data (if defined in the metadata)
Remove measurements deviating from limits defined in the metadata
Plot histograms
If group_vars is specified by the user, distributions within group-wise ecdf are presented.