names-set-.dataquieR_translated: 'names' implementation for the class 'dataquieR_translated'

names<-.dataquieR_translatedR Documentation

names implementation for the class dataquieR_translated

Description

dataquieR's translated texts featuring access to the language keys, still. this function returns the language keys.

Usage

## S3 replacement method for class 'dataquieR_translated'
names(x) <- value

Arguments

x

dataquieR_translated object

value

the names to assign

Details

only setNames(nm = x) is allowed for convenience. Any other assignment would mean to change the language keys, so this is not allowed.

Value

names of the underlying character vector

See Also

base::as.character


dataquieR documentation built on May 12, 2026, 1:06 a.m.