plot.dataquieR_summary: Plot a 'dataquieR' summary

View source: R/plot.dataquieR_summary.R

plot.dataquieR_summaryR Documentation

Plot a dataquieR summary

Description

Plot a dataquieR summary

Usage

## S3 method for class 'dataquieR_summary'
plot(
  x,
  y,
  ...,
  filter,
  dont_plot = FALSE,
  stratify_by,
  vars_to_include = "study",
  disable_plotly = FALSE,
  hierarchy,
  folder_of_report = NULL,
  var_uniquenames = NULL
)

Arguments

x

the dataquieR summary, see summary() and dq_report2()

y

not yet used

...

not yet used

filter

if given, this filters the summary, e.g., filter = call_names == "com_qualified_item_missingness"

dont_plot

suppress the actual plotting, just return a printable object derived from x

stratify_by

column to stratify the summary, may be one string.

vars_to_include

character study | ssi. variables are study variables or computed social science indicator variables.

disable_plotly

logical do not use plotly, even if installed

hierarchy

not yet defined, but if an argument is given, a sunburst chart is displayed, currently, only DQ_OBS can be used a the hierarchy.

folder_of_report

a named vector with the location of variable and call_names

var_uniquenames

a data frame with the original variable names and the unique names in case of reports created with dq_report_by containing the same variable in several reports (e.g., creation of reports by sex)

Value

invisible html object


dataquieR documentation built on May 12, 2026, 1:06 a.m.