will only warn and return a cleaned x.
util_ensure_in(x, set, err_msg, error = FALSE, applicability_problem = NA)character invisible(intersect(x, set))
character vector of needles
character vector representing the haystack
character optional error message. Use %s twice, once for the missing elements and once for proposals
logical if TRUE, the execution will stop with an error,
if not all x are elements of set, otherwise,
it will throw a warning and "clean" the vector x
from unexpected elements.
logical error indicates unsuitable resp_vars