does not warn on ambiguities nor if not found (but in the latter case,
it returns ifnotfound)
util_find_var_by_meta(
resp_vars,
meta_data = "item_level",
label_col = LABEL,
allowed_sources = c(VAR_NAMES, label_col, LABEL, LONG_LABEL, "ORIGINAL_VAR_NAMES",
"ORIGINAL_LABEL"),
target = VAR_NAMES,
ifnotfound = NA_character_
)vector of mapped target names of resp_vars
variables to map from
metadata
label-col to map from, if not allowed_sources should be
entirely passed
allowed names to map from (as metadata columns)
metadata attribute to map to
list A list of values to be used if the item is not found: it will be coerced to a list if necessary.
Other metadata_management:
CAN_THIS_BE_REMOVED_util_combine_missing_lists(),
util_dist_selection(),
util_find_free_missing_code(),
util_get_var_att_names_of_level(),
util_get_vars_in_segment(),
util_looks_like_missing(),
util_no_value_labels(),
util_validate_known_meta(),
util_validate_missing_lists()