| names<-.dataquieR_translated | R Documentation |
names implementation for the class dataquieR_translateddataquieR's translated texts featuring access to the language keys, still.
this function returns the language keys.
## S3 replacement method for class 'dataquieR_translated'
names(x) <- value
x |
|
value |
the names to assign |
only setNames(nm = x) is allowed for convenience. Any other assignment
would mean to change the language keys, so this is not allowed.
names of the underlying character vector
base::as.character
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.