View source: R/plot.dataquieR_summary.R
| plot.dataquieR_summary | R Documentation |
dataquieR summaryPlot a dataquieR summary
## S3 method for class 'dataquieR_summary'
plot(
x,
y,
...,
filter,
dont_plot = FALSE,
stratify_by,
vars_to_include = "study",
disable_plotly = FALSE,
hierarchy,
folder_of_report = NULL,
var_uniquenames = NULL
)
x |
the |
y |
not yet used |
... |
not yet used |
filter |
if given, this filters the summary, e.g.,
|
dont_plot |
suppress the actual plotting, just return a printable
object derived from |
stratify_by |
column to stratify the summary, may be one string. |
vars_to_include |
character study | |
disable_plotly |
logical do not use |
hierarchy |
not yet defined, but if an argument is given, a
sunburst chart is displayed, currently, only |
folder_of_report |
a named vector with the location of variable and
|
var_uniquenames |
a data frame with the original variable names and the unique names in case of reports created with dq_report_by containing the same variable in several reports (e.g., creation of reports by sex) |
invisible html object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.